@@ -1,16 +1,16 @@
 #!/usr/local/bin/perl
-# $Id: get_subontology_from.pl 2010-09-29 erick.antezana $
+# $Id: get_subontology_from.pl erick.antezana $
 #
 # Script  : get_subontology_from.pl
 #
 # Purpose : Given an OBO-formatted ontology (such as the Gene Ontology), this script 
 #           extracts a subontology (in OBO format) having as root node the provided term ID.
-#           This script can easily be adapted to get such subontology (branch) taking into
+#           This script can easily be adapted to get such a sub-ontology (branch) taking into
 #           account the name (or synonym) of a given term.
 #
 # Usage   : get_subontology_from.pl input_ontology.obo term_id > sub_ontology.obo
 #
-# License : Copyright (c) 2010 Erick Antezana. All rights reserved.
+# License : Copyright (C) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 #
@@ -29,7 +29,7 @@ my $my_large_onto = $my_parser->work(shift @ARGV);
 my $new_root      = $my_large_onto->get_term_by_id(shift @ARGV);
 die "The term, you have asked as being the new root, does not exist!\n" if (!$new_root);
 my $sub_ontology  = $my_large_onto->get_subontology_from($new_root);
-$sub_ontology->export(\*STDOUT, "obo");
+$sub_ontology->export('obo');
 
 exit 0;
 
@@ -47,7 +47,7 @@ get_subontology_from.pl input_ontology.obo term_id > sub_ontology.obo
 
 Given an OBO-formatted ontology (such as the Gene Ontology), this script 
 extracts a subontology (in OBO format) having as root node the provided term ID.
-This script can easily be adapted to get such subontology (branch) taking into
+This script can easily be adapted to get such a sub-ontology (branch) taking into
 account the name (or synonym) of a given term.
 
 =head1 AUTHOR
@@ -56,7 +56,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
