@@ -1,11 +1,11 @@
 #!/usr/local/bin/perl
-# $Id: obo2owl.pl 2010-09-29 erick.antezana $
+# $Id: obo2owl.pl 2011-02-29 erick.antezana $
 #
 # Script  : obo2owl.pl
 #
 # Purpose : Converts a file from OBO to OWL.
 #
-# Usage   : obo2owl.pl my_ontology.obo > my_ontology.owl
+# Usage   : obo2owl.pl my_ontology.obo > my_ontology.owl http://www.myurl.org http://www.myurl.org/oboInOwl#
 #
 # License : Copyright (c) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@ my $my_parser   = OBO::Parser::OBOParser->new();
 my $ontology    = $my_parser->work(shift);
 my $url         = shift;
 my $oboinowlurl = shift;
-$ontology->export('owl', \*STDOUT, $url, $oboinowlurl);
+$ontology->export('owl', \*STDOUT, \*STDERR, $url, $oboinowlurl);
 
 exit 0;
 
