@@ -8,7 +8,7 @@
 #           and identical terms (comparison done by term ID). A closer analysis should be done to 
 #           identify the differences.
 # Usage   : obo_intersection.pl my_first_ontology.obo my_second_ontology.obo > intersection.obo
-# License : Copyright (c) 2007, 2008, 2009, 2010 by Erick Antezana. All rights reserved.
+# License : Copyright (C) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -26,7 +26,7 @@ my $onto1       = $my_parser->work(shift @ARGV);
 my $onto2       = $my_parser->work(shift @ARGV);
 my $my_ontolome = OBO::Util::Ontolome->new();
 my $union       = $my_ontolome->intersection($onto1, $onto2);
-$union->export(\*STDOUT, "obo");
+$union->export('obo');
 
 exit 0;
 
@@ -50,7 +50,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007, 2008, 2009, 2010 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
